Struct rustutils_wc::Wc
source · [−]pub struct Wc {
pub bytes: bool,
pub chars: bool,
pub lines: bool,
pub words: bool,
pub json: bool,
pub files: Vec<PathBuf>,
}Expand description
Print newline, word, and byte counts for each file.
Fields
bytes: boolPrint the byte counts
chars: boolPrint the character counts (input is interpreted as UTF-8).
lines: boolPrint the line count.
words: boolPrint the word count.
json: boolOutput result as JSON.
files: Vec<PathBuf>Files to read, if not specified, standard input is read.
Implementations